@@ -434,31 +434,35 @@ class Error(Exception):
     pass
 
 
-# if __name__ == '__main__':
-#     host = '18.212.241.241'
-#     e6x_connection = connect(
-#         host=host,
-#         port=9001,
-#         scheme="e6xdb",
-#         username="admin",
-#         database="tpcds_1000",
-#         auth=None,
-#         configuration=None,
-#         kerberos_service_name=None,
-#         password="admin",
-#         check_hostname=None,
-#         ssl_cert=None,
-#         thrift_transport=None
-#     )
-#     print('Connected.')
-#     import time
-#     start = time.time()
-#     cursor = e6x_connection.cursor()
-#     query = 'SELECT * FROM date_dim limit 1;'
-#     cursor.execute(query)
-#     all_records = cursor.fetchall()
-#     print(time.time() - start)
-    # print(all_records)
+if __name__ == '__main__':
+    # host = '18.212.241.241'
+    host = '54.226.47.223'
+    e6x_connection = connect(
+        host=host,
+        port=9000,
+        scheme="e6xdb",
+        username="admin",
+        database="tpcds_1000",
+        auth=None,
+        configuration=None,
+        kerberos_service_name=None,
+        password="admin",
+        check_hostname=None,
+        ssl_cert=None,
+        thrift_transport=None
+    )
+    print('Connected.')
+    import time
+    start = time.time()
+    cursor = e6x_connection.cursor()
+    query = 'SELECT * FROM web_sales limit 10'
+    query_id = cursor.execute(query)
+    print(query_id)
+    # cursor.cancel(query_id)
+    all_records = cursor.fetchall()
+    print('Execution time', time.time() - start)
+    print('Length', len(all_records))
+    print(all_records)
     # e6x_connection.close()
 #
 #     e6x_connection.reopen()
